@@ -1,18 +1,17 @@
 import gi
-gi.require_version('Gtk', '3.0')
+
+gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
-from locale import gettext as _
-gi.require_version('Vte', '2.91')  # vte-0.42
-from gi.repository import Vte
+
 from guake.customcommands import CustomCommands
 
 import logging
+
 log = logging.getLogger(__name__)
 
 
 def mk_tab_context_menu(callback_object):
-    """Create the context menu for a notebook tab
-    """
+    """Create the context menu for a notebook tab"""
     # Store the menu in a temp variable in terminal so that popup() is happy. See:
     #   https://stackoverflow.com/questions/28465956/
     callback_object.context_menu = Gtk.Menu()
@@ -34,8 +33,7 @@ def mk_tab_context_menu(callback_object):
 
 
 def mk_notebook_context_menu(callback_object):
-    """Create the context menu for the notebook
-    """
+    """Create the context menu for the notebook"""
     callback_object.context_menu = Gtk.Menu()
     menu = callback_object.context_menu
     mi = Gtk.MenuItem(_("New Tab"))
@@ -70,8 +68,7 @@ FILE_SELECTION_LENGTH = 30
 
 
 def mk_terminal_context_menu(terminal, window, settings, callback_object):
-    """Create the context menu for a terminal.
-    """
+    """Create the context menu for a terminal."""
     # Store the menu in a temp variable in terminal so that popup() is happy. See:
     #   https://stackoverflow.com/questions/28465956/
     terminal.context_menu = Gtk.Menu()
@@ -80,7 +77,7 @@ def mk_terminal_context_menu(terminal, window, settings, callback_object):
     mi.connect("activate", callback_object.on_copy_clipboard)
     menu.add(mi)
     if get_link_under_cursor(terminal) is not None:
-        mi = Gtk.MenuItem(_("Copy Url"))
+        mi = Gtk.MenuItem(_("Copy URL"))
         mi.connect("activate", callback_object.on_copy_url_clipboard)
         menu.add(mi)
     mi = Gtk.MenuItem(_("Paste"))
@@ -123,7 +120,7 @@ def mk_terminal_context_menu(terminal, window, settings, callback_object):
     # implementation does not support this at the moment
     if link:
         if len(link) >= FILE_SELECTION_LENGTH:
-            mi.set_label(_("Open Link: {!s}...").format(link[:FILE_SELECTION_LENGTH - 3]))
+            mi.set_label(_("Open Link: {!s}...").format(link[: FILE_SELECTION_LENGTH - 3]))
         else:
             mi.set_label(_("Open Link: {!s}").format(link))
         mi.set_sensitive(True)
@@ -136,7 +133,7 @@ def mk_terminal_context_menu(terminal, window, settings, callback_object):
     if selection:
         search_text = selection.rstrip()
         if len(search_text) > SEARCH_SELECTION_LENGTH:
-            search_text = search_text[:SEARCH_SELECTION_LENGTH - 3] + "..."
+            search_text = search_text[: SEARCH_SELECTION_LENGTH - 3] + "..."
         mi.set_label(_("Search on Web: '%s'") % search_text)
         mi.set_sensitive(True)
     else:
@@ -150,7 +147,7 @@ def mk_terminal_context_menu(terminal, window, settings, callback_object):
             filename_str = str(filename)
             if len(filename_str) > FILE_SELECTION_LENGTH:
                 mi.set_label(
-                    _("Quick Open: {!s}...").format(filename_str[:FILE_SELECTION_LENGTH - 3])
+                    _("Quick Open: {!s}...").format(filename_str[: FILE_SELECTION_LENGTH - 3])
                 )
             else:
                 mi.set_label(_("Quick Open: {!s}").format(filename_str))
