@@ -19,7 +19,6 @@ Boston, MA 02110-1301 USA
 """
 
 from guake.about import AboutDialog
-from guake.boxes import DualTerminalBox
 from guake.boxes import RootTerminalBox
 from guake.boxes import TabLabelEventBox
 from guake.boxes import TerminalBox
@@ -33,14 +32,14 @@ from guake.utils import save_tabs_when_changed
 
 import gi
 import os
-gi.require_version('Gtk', '3.0')
-gi.require_version('Wnck', '3.0')
+
+gi.require_version("Gtk", "3.0")
+gi.require_version("Wnck", "3.0")
 from gi.repository import GObject
 from gi.repository import Gdk
 from gi.repository import Gtk
 from gi.repository import Wnck
 from guake.terminal import GuakeTerminal
-from locale import gettext as _
 
 import logging
 import posix
@@ -49,7 +48,6 @@ log = logging.getLogger(__name__)
 
 
 class TerminalNotebook(Gtk.Notebook):
-
     def __init__(self, *args, **kwargs):
         Gtk.Notebook.__init__(self, *args, **kwargs)
         self.last_terminal_focused = None
@@ -66,35 +64,43 @@ class TerminalNotebook(Gtk.Notebook):
         self.set_property("is-focus", True)
         self.set_property("expand", True)
 
-        if GObject.signal_lookup('terminal-spawned', TerminalNotebook) == 0:
+        if GObject.signal_lookup("terminal-spawned", TerminalNotebook) == 0:
             GObject.signal_new(
-                'terminal-spawned', TerminalNotebook, GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE,
-                (GObject.TYPE_PYOBJECT, GObject.TYPE_INT)
+                "terminal-spawned",
+                TerminalNotebook,
+                GObject.SIGNAL_RUN_LAST,
+                GObject.TYPE_NONE,
+                (GObject.TYPE_PYOBJECT, GObject.TYPE_INT),
             )
             GObject.signal_new(
-                'page-deleted', TerminalNotebook, GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE, ()
+                "page-deleted",
+                TerminalNotebook,
+                GObject.SIGNAL_RUN_LAST,
+                GObject.TYPE_NONE,
+                (),
             )
 
         self.scroll_callback = NotebookScrollCallback(self)
         self.add_events(Gdk.EventMask.SCROLL_MASK)
-        self.connect('scroll-event', self.scroll_callback.on_scroll)
+        self.connect("scroll-event", self.scroll_callback.on_scroll)
         self.notebook_on_button_press_id = self.connect(
             "button-press-event", self.on_button_press, None
         )
 
         # Action box
         self.new_page_button = Gtk.Button(
-            image=Gtk.Image.new_from_icon_name("tab-new", Gtk.IconSize.MENU), visible=True
+            image=Gtk.Image.new_from_icon_name("tab-new-symbolic", Gtk.IconSize.MENU),
+            visible=True,
         )
         self.new_page_button.connect("clicked", self.on_new_tab)
 
         self.tab_selection_button = Gtk.Button(
-            image=Gtk.Image.new_from_icon_name('pan-down-symbolic', Gtk.IconSize.MENU),
-            visible=True
+            image=Gtk.Image.new_from_icon_name("pan-down-symbolic", Gtk.IconSize.MENU),
+            visible=True,
         )
         self.popover = Gtk.Popover()
         self.popover_window = None
-        self.tab_selection_button.connect('clicked', self.on_tab_selection)
+        self.tab_selection_button.connect("clicked", self.on_tab_selection)
 
         self.action_box = Gtk.Box(visible=True)
         self.action_box.pack_start(self.new_page_button, 0, 0, 0)
@@ -115,9 +121,6 @@ class TerminalNotebook(Gtk.Notebook):
                 # Gtk 3.18 fallback ("'Menu' object has no attribute 'popup_at_pointer'")
                 menu.popup(None, None, None, None, event.button, event.time)
 
-        elif event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS and event.button == 1:
-            self.new_page_with_focus()
-
         return False
 
     @save_tabs_when_changed
@@ -139,22 +142,27 @@ class TerminalNotebook(Gtk.Notebook):
         # ref: epiphany
         css_provider = Gtk.CssProvider()
         css_provider.load_from_data(
-            b'#popover-window list { border-style: none; background-color: transparent; }'
+            b"#popover-window list { border-style: none; background-color: transparent; }"
         )
         Gtk.StyleContext.add_provider_for_screen(
-            Gdk.Screen.get_default(), css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
+            Gdk.Screen.get_default(),
+            css_provider,
+            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION,
         )
 
         # Construct popover properties
         BOX_HEIGHT = 30
         LISTBOX_MARGIN = 12
-        self.popover_window = Gtk.ScrolledWindow(name='popover-window')
+        self.popover_window = Gtk.ScrolledWindow(name="popover-window")
         self.popover_listbox = Gtk.ListBox()
-        self.popover_listbox.set_property('margin', LISTBOX_MARGIN)
+        self.popover_listbox.set_property("margin", LISTBOX_MARGIN)
         self.popover_window.add_with_viewport(self.popover_listbox)
 
-        max_height = self.guake.window.get_allocation().height - BOX_HEIGHT if \
-            self.guake else BOX_HEIGHT * 10
+        max_height = (
+            self.guake.window.get_allocation().height - BOX_HEIGHT
+            if self.guake
+            else BOX_HEIGHT * 10
+        )
         height = BOX_HEIGHT * self.get_n_pages() + LISTBOX_MARGIN * 4
         self.popover_window.set_min_content_height(min(max_height, height))
         self.popover_window.set_min_content_width(325)
@@ -171,14 +179,14 @@ class TerminalNotebook(Gtk.Notebook):
             label.set_xalign(0.0)
             box.pack_start(label, 0, 0, 5)
             row.add(box)
-            setattr(row, 'page_index', i)
+            setattr(row, "page_index", i)
             self.popover_listbox.add(row)
             if current_term in self.get_terminals_for_page(i):
                 self.popover_listbox.select_row(row)
                 selected_row = i
 
         # Signal
-        self.popover_listbox.connect('row-activated', self.on_popover_tab_select)
+        self.popover_listbox.connect("row-activated", self.on_popover_tab_select)
 
         # Show popup
         self.popover.set_position(Gtk.PositionType.TOP)
@@ -201,13 +209,13 @@ class TerminalNotebook(Gtk.Notebook):
             adj.set_value(part * (selected_row + 1))
 
     def on_popover_tab_select(self, list_box, row):
-        page_index = getattr(row, 'page_index', -1)
+        page_index = getattr(row, "page_index", -1)
         if page_index != -1:
             self.set_current_page(page_index)
             self.get_terminals_for_page(page_index)[0].grab_focus()
 
     def set_tabbar_visible(self, v):
-        self.set_property('show-tabs', v)
+        self.set_property("show-tabs", v)
 
     def set_last_terminal_focused(self, terminal):
         self.last_terminal_focused = terminal
@@ -253,7 +261,8 @@ class TerminalNotebook(Gtk.Notebook):
                     total_procs += 1
             except OSError:
                 log.debug(
-                    "Cannot retrieve any pid from terminal %s, looks like it is already dead", index
+                    "Cannot retrieve any pid from terminal %s, looks like it is already dead",
+                    index,
                 )
                 return 0
         return total_procs
@@ -285,7 +294,7 @@ class TerminalNotebook(Gtk.Notebook):
         procs = self.get_running_fg_processes_count_page(page_num)
         if prompt == 2 or (prompt == 1 and procs > 0):
             # TODO NOTEBOOK remove call to guake
-            if not PromptQuitDialog(self.guake.window, procs, -1).close_tab():
+            if not PromptQuitDialog(self.guake.window, procs, -1, None).close_tab():
                 return
 
         page = self.get_nth_page(page_num)
@@ -314,7 +323,9 @@ class TerminalNotebook(Gtk.Notebook):
             page = self.get_nth_page(self.get_current_page())
             if page.get_terminals():
                 page.get_terminals()[0].grab_focus()
-        self.emit('page-deleted')
+
+        self.hide_tabbar_if_one_tab()
+        self.emit("page-deleted")
 
     def delete_page_by_label(self, label, kill=True, prompt=0):
         self.delete_page(self.find_tab_index_by_label(label), kill, prompt)
@@ -341,25 +352,43 @@ class TerminalNotebook(Gtk.Notebook):
         # this is needed to initially set the last_terminal_focused,
         # one could also call terminal.get_parent().on_terminal_focus()
         self.terminal_attached(terminal)
+        self.hide_tabbar_if_one_tab()
+
+        if self.guake:
+            # Attack background image draw callback to root terminal box
+            root_terminal_box.connect_after("draw", self.guake.background_image_manager.draw)
         return root_terminal_box, page_num, terminal
 
+    def hide_tabbar_if_one_tab(self):
+        """Hide the tab bar if hide-tabs-if-one-tab is true and there is only one
+        notebook page"""
+        if self.guake.settings.general.get_boolean("window-tabbar"):
+            if self.guake.settings.general.get_boolean("hide-tabs-if-one-tab"):
+                self.set_property("show-tabs", self.get_n_pages() != 1)
+            else:
+                self.set_property("show-tabs", True)
+
     def terminal_spawn(self, directory=None):
         terminal = GuakeTerminal(self.guake)
         terminal.grab_focus()
+        terminal.connect(
+            "key-press-event",
+            lambda x, y: self.guake.accel_group.activate(x, y) if self.guake.accel_group else False,
+        )
         if not isinstance(directory, str):
-            directory = os.environ['HOME']
+            directory = os.environ["HOME"]
             try:
-                if self.guake.settings.general.get_boolean('open-tab-cwd'):
+                if self.guake.settings.general.get_boolean("open-tab-cwd"):
                     # Do last focused terminal still alive?
                     active_terminal = self.get_current_terminal()
                     if not active_terminal:
                         # If not alive, can we get any focused terminal?
                         active_terminal = self.get_focused_terminal()
-                    directory = os.path.expanduser('~')
+                    directory = os.path.expanduser("~")
                     if active_terminal:
                         # If found, we will use its directory as new terminal's directory
                         directory = active_terminal.get_current_directory()
-            except Exception as e:
+            except BaseException:
                 pass
         log.info("Spawning new terminal at %s", directory)
         terminal.spawn_sync_pid(directory)
@@ -367,7 +396,7 @@ class TerminalNotebook(Gtk.Notebook):
 
     def terminal_attached(self, terminal):
         terminal.emit("focus", Gtk.DirectionType.TAB_FORWARD)
-        self.emit('terminal-spawned', terminal, terminal.pid)
+        self.emit("terminal-spawned", terminal, terminal.pid)
 
     def new_page_with_focus(self, directory=None, label=None, user_set=False, position=None):
         box, page_num, terminal = self.new_page(directory, position=position)
@@ -392,7 +421,7 @@ class TerminalNotebook(Gtk.Notebook):
             else:
                 label = TabLabelEventBox(self, new_text, self.guake.settings)
                 label.add_events(Gdk.EventMask.SCROLL_MASK)
-                label.connect('scroll-event', self.scroll_callback.on_scroll)
+                label.connect("scroll-event", self.scroll_callback.on_scroll)
 
                 self.set_tab_label(page, label)
             if user_set:
@@ -440,12 +469,12 @@ class TerminalNotebook(Gtk.Notebook):
             flags=Gtk.DialogFlags.MODAL,
             buttons=Gtk.ButtonsType.OK_CANCEL,
             message_format=_(
-                'You are going to restore *all* the tabs!\n'
-                'which means all your terminals & pages '
-                'will be replaced.\n\nDo you want to continue?'
-            )
+                "You are going to restore *all* the tabs!\n"
+                "which means all your terminals & pages "
+                "will be replaced.\n\nDo you want to continue?"
+            ),
         )
-        dialog.connect('response', self.restore_tabs_dialog_response)
+        dialog.connect("response", self.restore_tabs_dialog_response)
         dialog.show()
 
     def restore_tabs_dialog_response(self, widget, response_id):
@@ -455,15 +484,22 @@ class TerminalNotebook(Gtk.Notebook):
 
 
 class NotebookManager(GObject.Object):
-
     def __init__(
-        self, window, notebook_parent, workspaces_enabled, terminal_spawned_cb, page_deleted_cb
+        self,
+        window,
+        notebook_parent,
+        workspaces_enabled,
+        terminal_spawned_cb,
+        page_deleted_cb,
     ):
         GObject.Object.__init__(self)
-        if not GObject.signal_lookup('notebook-created', self):
+        if not GObject.signal_lookup("notebook-created", self):
             GObject.signal_new(
-                'notebook-created', self, GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE,
-                (GObject.TYPE_PYOBJECT, GObject.TYPE_INT)
+                "notebook-created",
+                self,
+                GObject.SIGNAL_RUN_LAST,
+                GObject.TYPE_NONE,
+                (GObject.TYPE_PYOBJECT, GObject.TYPE_INT),
             )
         self.current_notebook = 0
         self.notebooks = {}
@@ -485,9 +521,9 @@ class NotebookManager(GObject.Object):
     def get_notebook(self, workspace_index: int):
         if not self.has_notebook_for_workspace(workspace_index):
             self.notebooks[workspace_index] = TerminalNotebook()
-            self.emit('notebook-created', self.notebooks[workspace_index], workspace_index)
-            self.notebooks[workspace_index].connect('terminal-spawned', self.terminal_spawned_cb)
-            self.notebooks[workspace_index].connect('page-deleted', self.page_deleted_cb)
+            self.emit("notebook-created", self.notebooks[workspace_index], workspace_index)
+            self.notebooks[workspace_index].connect("terminal-spawned", self.terminal_spawned_cb)
+            self.notebooks[workspace_index].connect("page-deleted", self.page_deleted_cb)
             log.info("created fresh notebook for workspace %d", self.current_notebook)
 
             # add a tab if there is none
@@ -500,7 +536,7 @@ class NotebookManager(GObject.Object):
         return self.get_notebook(self.current_notebook)
 
     def has_notebook_for_workspace(self, workspace_index):
-        return workspace_index in self.notebooks.keys()
+        return workspace_index in self.notebooks
 
     def set_workspace(self, index: int):
         self.notebook_parent.remove(self.get_current_notebook())
@@ -508,13 +544,15 @@ class NotebookManager(GObject.Object):
         log.info("current workspace is %d", self.current_notebook)
         notebook = self.get_current_notebook()
         self.notebook_parent.add(notebook)
-        if self.window.get_property('visible') and \
-                notebook.last_terminal_focused is not None:
+        if self.window.get_property("visible") and notebook.last_terminal_focused is not None:
             notebook.last_terminal_focused.grab_focus()
 
         # Restore pending page terminal split
         notebook.guake.restore_pending_terminal_split()
 
+        # Restore config to workspace
+        notebook.guake.load_config()
+
     def set_notebooks_tabbar_visible(self, v):
         for nb in self.iter_notebooks():
             nb.set_tabbar_visible(v)
